@@ -15,12 +15,12 @@ import drest
 import drest.exc
 import drest.serialization
 
-import src.requesthandler
+from .requesthandler import RequestHandler
 
 __original_author__ = "Markus Juenemann <markus@juenemann.net>"
 __author__ = "Pierre-Aymeric MASSE"
 __mail__ = "cto@kandu.fr"
-__version__ = "0.3.2"
+__version__ = "0.3.3"
 __license__ = 'BSD 2-clause "Simplified" License'
 
 SIGFOX_API_URL = "https://api.sigfox.com/v2/"
@@ -214,7 +214,7 @@ class Sigfox(object):
             deserialize=True,
             ignore_ssl_validation=IGNORE_SSL_VALIDATION,
             trailing_slash=False,
-            request_handler=sigfoxapi.requesthandler.RequestHandler,
+            request_handler=RequestHandler,
         )
         self.api.auth(login, password)
         print('new')
